@@ -61,11 +61,6 @@ class BinnedPrecisionRecallCurve(Metric):
         thresholds: list or tensor with specific thresholds or a number of bins from linear sampling.
             It is used for computation will lead to more detailed curve and accurate estimates,
             but will be slower and consume more memory.
-        compute_on_step:
-            Forward only calls ``update()`` and returns None if this is set to False.
-
-            .. deprecated:: v0.8
-                Argument has no use anymore and will be removed v0.9.
 
         kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
@@ -114,6 +109,9 @@ class BinnedPrecisionRecallCurve(Metric):
         tensor([0.0000, 0.5000, 1.0000])]
     """
 
+    is_differentiable: bool = False
+    higher_is_better: Optional[bool] = None
+    full_state_update: bool = False
     TPs: Tensor
     FPs: Tensor
     FNs: Tensor
@@ -122,22 +120,20 @@ class BinnedPrecisionRecallCurve(Metric):
         self,
         num_classes: int,
         thresholds: Union[int, Tensor, List[float]] = 100,
-        compute_on_step: Optional[bool] = None,
         **kwargs: Dict[str, Any],
     ) -> None:
-        super().__init__(compute_on_step=compute_on_step, **kwargs)
+        super().__init__(**kwargs)
 
         self.num_classes = num_classes
         if isinstance(thresholds, int):
             self.num_thresholds = thresholds
-            thresholds = torch.linspace(0, 1.0, thresholds)
-            self.register_buffer("thresholds", thresholds)
+            self.thresholds = torch.linspace(0, 1.0, thresholds)
+
         elif thresholds is not None:
             if not isinstance(thresholds, (list, Tensor)):
                 raise ValueError("Expected argument `thresholds` to either be an integer, list of floats or a tensor")
-            thresholds = torch.tensor(thresholds) if isinstance(thresholds, list) else thresholds
-            self.num_thresholds = thresholds.numel()
-            self.register_buffer("thresholds", thresholds)
+            self.thresholds = torch.tensor(thresholds) if isinstance(thresholds, list) else thresholds
+            self.num_thresholds = self.thresholds.numel()
 
         for name in ("TPs", "FPs", "FNs"):
             self.add_state(
@@ -203,11 +199,6 @@ class BinnedAveragePrecision(BinnedPrecisionRecallCurve):
         thresholds: list or tensor with specific thresholds or a number of bins from linear sampling.
             It is used for computation will lead to more detailed curve and accurate estimates,
             but will be slower and consume more memory
-        compute_on_step:
-            Forward only calls ``update()`` and returns None if this is set to False.
-
-            .. deprecated:: v0.8
-                Argument has no use anymore and will be removed v0.9.
 
         kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
@@ -258,11 +249,6 @@ class BinnedRecallAtFixedPrecision(BinnedPrecisionRecallCurve):
         thresholds: list or tensor with specific thresholds or a number of bins from linear sampling.
             It is used for computation will lead to more detailed curve and accurate estimates,
             but will be slower and consume more memory
-        compute_on_step:
-            Forward only calls ``update()`` and returns None if this is set to False.
-
-            .. deprecated:: v0.8
-                Argument has no use anymore and will be removed v0.9.
 
         kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
@@ -295,10 +281,9 @@ class BinnedRecallAtFixedPrecision(BinnedPrecisionRecallCurve):
         num_classes: int,
         min_precision: float,
         thresholds: Union[int, Tensor, List[float]] = 100,
-        compute_on_step: Optional[bool] = None,
         **kwargs: Dict[str, Any],
     ) -> None:
-        super().__init__(num_classes=num_classes, thresholds=thresholds, compute_on_step=compute_on_step, **kwargs)
+        super().__init__(num_classes=num_classes, thresholds=thresholds, **kwargs)
         self.min_precision = min_precision
 
     def compute(self) -> Tuple[Tensor, Tensor]:  # type: ignore
