@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List
 
 import torch
 from torch import Tensor
@@ -52,16 +52,13 @@ class CalibrationError(Metric):
         norm: Norm used to compare empirical and expected probability bins.
             Defaults to "l1", or Expected Calibration Error.
         debias: Applies debiasing term, only implemented for l2 norm. Defaults to True.
-        compute_on_step:
-            Forward only calls ``update()`` and returns None if this is set to False.
-
-            .. deprecated:: v0.8
-                Argument has no use anymore and will be removed v0.9.
 
         kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
     """
+    is_differentiable: bool = False
+    higher_is_better: bool = False
+    full_state_update: bool = False
     DISTANCES = {"l1", "l2", "max"}
-    higher_is_better = False
     confidences: List[Tensor]
     accuracies: List[Tensor]
 
@@ -69,11 +66,10 @@ class CalibrationError(Metric):
         self,
         n_bins: int = 15,
         norm: str = "l1",
-        compute_on_step: Optional[bool] = None,
         **kwargs: Dict[str, Any],
     ):
 
-        super().__init__(compute_on_step=compute_on_step, **kwargs)
+        super().__init__(**kwargs)
 
         if norm not in self.DISTANCES:
             raise ValueError(f"Norm {norm} is not supported. Please select from l1, l2, or max. ")
@@ -81,7 +77,7 @@ class CalibrationError(Metric):
         if not isinstance(n_bins, int) or n_bins <= 0:
             raise ValueError(f"Expected argument `n_bins` to be a int larger than 0 but got {n_bins}")
         self.n_bins = n_bins
-        self.register_buffer("bin_boundaries", torch.linspace(0, 1, n_bins + 1))
+        self.bin_boundaries = torch.linspace(0, 1, n_bins + 1)
         self.norm = norm
 
         self.add_state("confidences", [], dist_reduce_fx="cat")
@@ -108,4 +104,4 @@ class CalibrationError(Metric):
         """
         confidences = dim_zero_cat(self.confidences)
         accuracies = dim_zero_cat(self.accuracies)
-        return _ce_compute(confidences, accuracies, self.bin_boundaries, norm=self.norm)
+        return _ce_compute(confidences, accuracies, self.bin_boundaries.to(self.device), norm=self.norm)
