@@ -56,12 +56,6 @@ class CohenKappa(Metric):
             Threshold for transforming probability or logit predictions to binary ``(0,1)`` predictions, in the case
             of binary or multi-label inputs. Default value of ``0.5`` corresponds to input being probabilities.
 
-        compute_on_step:
-            Forward only calls ``update()`` and returns ``None`` if this is set to ``False``.
-
-            .. deprecated:: v0.8
-                Argument has no use anymore and will be removed v0.9.
-
         kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
     Example:
@@ -73,8 +67,9 @@ class CohenKappa(Metric):
         tensor(0.5000)
 
     """
-    is_differentiable = False
-    higher_is_better = True
+    is_differentiable: bool = False
+    higher_is_better: bool = True
+    full_state_update: bool = False
     confmat: Tensor
 
     def __init__(
@@ -82,10 +77,9 @@ class CohenKappa(Metric):
         num_classes: int,
         weights: Optional[str] = None,
         threshold: float = 0.5,
-        compute_on_step: Optional[bool] = None,
         **kwargs: Dict[str, Any],
     ) -> None:
-        super().__init__(compute_on_step=compute_on_step, **kwargs)
+        super().__init__(**kwargs)
         self.num_classes = num_classes
         self.weights = weights
         self.threshold = threshold
