@@ -54,11 +54,6 @@ class ConfusionMatrix(Metric):
             of binary or multi-label inputs. Default value of ``0.5`` corresponds to input being probabilities.
 
         multilabel: determines if data is multilabel or not.
-        compute_on_step:
-            Forward only calls ``update()`` and returns None if this is set to False.
-
-            .. deprecated:: v0.8
-                Argument has no use anymore and will be removed v0.9.
 
         kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
@@ -90,7 +85,9 @@ class ConfusionMatrix(Metric):
                 [[0, 1], [0, 1]]])
 
     """
-    is_differentiable = False
+    is_differentiable: bool = False
+    higher_is_better: Optional[bool] = None
+    full_state_update: bool = False
     confmat: Tensor
 
     def __init__(
@@ -99,10 +96,9 @@ class ConfusionMatrix(Metric):
         normalize: Optional[str] = None,
         threshold: float = 0.5,
         multilabel: bool = False,
-        compute_on_step: Optional[bool] = None,
         **kwargs: Dict[str, Any],
     ) -> None:
-        super().__init__(compute_on_step=compute_on_step, **kwargs)
+        super().__init__(**kwargs)
         self.num_classes = num_classes
         self.normalize = normalize
         self.threshold = threshold
