@@ -13,7 +13,6 @@
 # limitations under the License.
 import functools
 import inspect
-import warnings
 from abc import ABC, abstractmethod
 from contextlib import contextmanager
 from copy import deepcopy
@@ -61,36 +60,6 @@ class Metric(Module, ABC):
         automatically calls ``update()`` and also returns the metric value at the current step.
 
     Args:
-        compute_on_step:
-            Forward only calls ``update()`` and returns None if this is set to False.
-
-            .. deprecated:: v0.8
-                Argument has no use anymore and will be removed v0.9.
-
-        dist_sync_on_step:
-            Synchronize metric state across processes at each ``forward()``
-            before returning the value at the step.
-
-            .. deprecated:: v0.8
-                Argument is deprecated and will be removed in v0.9 in favour of instead
-                passing it in as keyword argument.
-
-        process_group:
-            Specify the process group on which synchronization is called. Defaults is `None`
-            which selects the entire world
-
-            .. deprecated:: v0.8
-                Argument is deprecated and will be removed in v0.9 in favour of instead
-                passing it in as keyword argument.
-
-        dist_sync_fn:
-            Callback that performs the allgather operation on the metric state. When `None`, DDP
-            will be used to perform the allgather.
-
-            .. deprecated:: v0.8
-                Argument is deprecated and will be removed in v0.9 in favour of instead
-                passing it in as keyword argument.
-
         kwargs: additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
             - compute_on_cpu: If metric state should be stored on CPU during computations. Only works
@@ -104,11 +73,11 @@ class Metric(Module, ABC):
     __jit_unused_properties__ = ["is_differentiable"]
     is_differentiable: Optional[bool] = None
     higher_is_better: Optional[bool] = None
+    full_state_update: Optional[bool] = None
 
     def __init__(
         self,
-        compute_on_step: Optional[bool] = None,
-        **kwargs: Dict[str, Any],
+        **kwargs: Any,
     ) -> None:
         super().__init__()
 
@@ -118,10 +87,6 @@ class Metric(Module, ABC):
 
         self._device = torch.device("cpu")
 
-        if compute_on_step is not None:
-            warnings.warn(
-                "Argument `compute_on_step` is deprecated in v0.8 and will be removed in v0.9", DeprecationWarning
-            )
         self.compute_on_cpu = kwargs.pop("compute_on_cpu", False)
         if not isinstance(self.compute_on_cpu, bool):
             raise ValueError(
@@ -148,7 +113,7 @@ class Metric(Module, ABC):
         self.compute: Callable = self._wrap_compute(self.compute)  # type: ignore
         self._computed = None
         self._forward_cache = None
-        self._update_called = False
+        self._update_count = 0
         self._to_sync = True
         self._should_unsync = True
         self._enable_grad = False
@@ -162,6 +127,25 @@ class Metric(Module, ABC):
         self._is_synced = False
         self._cache: Optional[Dict[str, Union[List[Tensor], Tensor]]] = None
 
+        if self.full_state_update is None:
+            rank_zero_warn(
+                f"""Torchmetrics v0.9 introduced a new argument class property called `full_state_update` that has
+                not been set for this class ({self.__class__.__name__}). The property determines if `update` by
+                default needs access to the full metric state. If this is not the case, significant speedups can be
+                achieved and we recommend setting this to `False`.
+                We provide an checking function
+                `from torchmetrics.utilities import check_forward_no_full_state`
+                that can be used to check if the `full_state_update=True` (old and potential slower behaviour,
+                default for now) or if `full_state_update=False` can be used safely.
+                """,
+                UserWarning,
+            )
+
+    @property
+    def _update_called(self) -> bool:
+        # Needed for lightning integration
+        return self._update_count > 0
+
     def add_state(
         self,
         name: str,
@@ -233,19 +217,35 @@ class Metric(Module, ABC):
 
     @torch.jit.unused
     def forward(self, *args: Any, **kwargs: Any) -> Any:
-        """Automatically calls ``update()``.
+        """``forward`` serves the dual purpose of both computing the metric on the current batch of inputs but also
+        add the batch statistics to the overall accumululating metric state.
 
-        Returns the metric value over inputs if ``compute_on_step`` is True.
+        Input arguments are the exact same as corresponding ``update`` method. The returned output is the exact same as
+        the output of ``compute``.
         """
-        # add current step
+        # check if states are already synced
         if self._is_synced:
             raise TorchMetricsUserError(
-                "The Metric shouldn't be synced when performing ``update``. "
+                "The Metric shouldn't be synced when performing ``forward``. "
                 "HINT: Did you forget to call ``unsync`` ?."
             )
 
+        if self.full_state_update or self.full_state_update is None or self.dist_sync_on_step:
+            self._forward_cache = self._forward_full_state_update(*args, **kwargs)
+        else:
+            self._forward_cache = self._forward_reduce_state_update(*args, **kwargs)
+
+        return self._forward_cache
+
+    def _forward_full_state_update(self, *args: Any, **kwargs: Any) -> Any:
+        """forward computation using two calls to `update` to calculate the metric value on the current batch and
+        accumulate global state.
+
+        Doing this secures that metrics that need access to the full metric state during `update` works as expected.
+        """
         # global accumulation
         self.update(*args, **kwargs)
+        _update_count = self._update_count
 
         self._to_sync = self.dist_sync_on_step  # type: ignore
         # skip restore cache operation from compute as cache is stored below.
@@ -261,20 +261,87 @@ class Metric(Module, ABC):
         self._enable_grad = True  # allow grads for batch computation
         self.reset()
         self.update(*args, **kwargs)
-        self._forward_cache = self.compute()
+        batch_val = self.compute()
 
         # restore context
         for attr, val in cache.items():
             setattr(self, attr, val)
-        self._is_synced = False
+        self._update_count = _update_count
 
+        # restore context
+        self._is_synced = False
         self._should_unsync = True
         self._to_sync = True
         self._computed = None
         self._enable_grad = False
         self.compute_on_cpu = _temp_compute_on_cpu
 
-        return self._forward_cache
+        return batch_val
+
+    def _forward_reduce_state_update(self, *args: Any, **kwargs: Any) -> Any:
+        """forward computation using single call to `update` to calculate the metric value on the current batch and
+        accumulate global state.
+
+        This can be done when the global metric state is a sinple reduction of batch states.
+        """
+        # store global state and reset to default
+        global_state = {attr: getattr(self, attr) for attr in self._defaults.keys()}
+        _update_count = self._update_count
+        self.reset()
+
+        # local syncronization settings
+        self._to_sync = self.dist_sync_on_step
+        self._should_unsync = False
+        _temp_compute_on_cpu = self.compute_on_cpu
+        self.compute_on_cpu = False
+        self._enable_grad = True  # allow grads for batch computation
+
+        # calculate batch state and compute batch value
+        self.update(*args, **kwargs)
+        batch_val = self.compute()
+
+        # reduce batch and global state
+        self._update_count = _update_count + 1
+        self._reduce_states(global_state)
+
+        # restore context
+        self._is_synced = False
+        self._should_unsync = True
+        self._to_sync = True
+        self._computed = None
+        self._enable_grad = False
+        self.compute_on_cpu = _temp_compute_on_cpu
+
+        return batch_val
+
+    def _reduce_states(self, incoming_state: Dict[str, Any]) -> None:
+        """Adds an incoming metric state to the current state of the metric.
+
+        Args:
+            incoming_state: a dict containing a metric state similar metric itself
+        """
+        for attr in self._defaults.keys():
+            local_state = getattr(self, attr)
+            global_state = incoming_state[attr]
+            reduce_fn = self._reductions[attr]
+            if reduce_fn == dim_zero_sum:
+                reduced = global_state + local_state
+            elif reduce_fn == dim_zero_mean:
+                reduced = ((self._update_count - 1) * global_state + local_state) / self._update_count
+            elif reduce_fn == dim_zero_max:
+                reduced = torch.max(global_state, local_state)
+            elif reduce_fn == dim_zero_min:
+                reduced = torch.min(global_state, local_state)
+            elif reduce_fn == dim_zero_cat:
+                reduced = global_state + local_state
+            elif reduce_fn is None and isinstance(global_state, Tensor):
+                reduced = torch.stack([global_state, local_state])
+            elif reduce_fn is None and isinstance(global_state, list):
+                reduced = _flatten([global_state, local_state])
+            else:
+                reduced = reduce_fn(torch.stack([global_state, local_state]))  # type: ignore
+
+            setattr(self, attr, reduced)
 
     def _sync_dist(self, dist_sync_fn: Callable = gather_all_tensors, process_group: Optional[Any] = None) -> None:
         input_dict = {attr: getattr(self, attr) for attr in self._reductions}
@@ -293,6 +360,7 @@ class Metric(Module, ABC):
 
         for attr, reduction_fn in self._reductions.items():
             # pre-processing ops (stack or flatten for inputs)
+
             if isinstance(output_dict[attr][0], Tensor):
                 output_dict[attr] = torch.stack(output_dict[attr])
             elif isinstance(output_dict[attr][0], list):
@@ -307,7 +375,7 @@ class Metric(Module, ABC):
         @functools.wraps(update)
         def wrapped_func(*args: Any, **kwargs: Any) -> None:
             self._computed = None
-            self._update_called = True
+            self._update_count += 1
             with torch.set_grad_enabled(self._enable_grad):
                 update(*args, **kwargs)
             if self.compute_on_cpu:
@@ -417,7 +485,7 @@ class Metric(Module, ABC):
     def _wrap_compute(self, compute: Callable) -> Callable:
         @functools.wraps(compute)
         def wrapped_func(*args: Any, **kwargs: Any) -> Any:
-            if not self._update_called:
+            if self._update_count == 0:
                 rank_zero_warn(
                     f"The ``compute`` method of metric {self.__class__.__name__}"
                     " was called before the ``update`` method which may lead to errors,"
@@ -455,7 +523,7 @@ class Metric(Module, ABC):
 
     def reset(self) -> None:
         """This method automatically resets the metric state variables to their default value."""
-        self._update_called = False
+        self._update_count = 0
         self._forward_cache = None
         self._computed = None
 
@@ -486,7 +554,7 @@ class Metric(Module, ABC):
         self.compute: Callable = self._wrap_compute(self.compute)  # type: ignore
 
     def __setattr__(self, name: str, value: Any) -> None:
-        if name in ("higher_is_better", "is_differentiable"):
+        if name in ("higher_is_better", "is_differentiable", "full_state_update"):
             raise RuntimeError(f"Can't change const `{name}`.")
         super().__setattr__(name, value)
 
@@ -835,12 +903,10 @@ class CompositionalMetric(Metric):
         )
 
         if val_a is None:
-            # compute_on_step of metric_a is False
             return None
 
         if val_b is None:
             if isinstance(self.metric_b, Metric):
-                # compute_on_step of metric_b is False
                 return None
 
             # Unary op
