@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, Dict, Optional
+from typing import Any, Dict
 
 import torch
 from torch import Tensor
@@ -54,12 +54,6 @@ class TweedieDevianceScore(Metric):
             - power = 3 : Inverse Gaussian distribution. (Requires: targets > 0 and preds > 0.)
             - otherwise : Positive stable distribution. (Requires: targets > 0 and preds > 0.)
 
-        compute_on_step:
-            Forward only calls ``update()`` and returns None if this is set to False.
-
-            .. deprecated:: v0.8
-                Argument has no use anymore and will be removed v0.9.
-
         kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
     Example:
@@ -71,18 +65,18 @@ class TweedieDevianceScore(Metric):
         tensor(1.2083)
 
     """
-    is_differentiable = True
+    is_differentiable: bool = True
     higher_is_better = None  # TODO: both -1 and 1 are optimal
+    full_state_update: bool = False
     sum_deviance_score: Tensor
     num_observations: Tensor
 
     def __init__(
         self,
         power: float = 0.0,
-        compute_on_step: Optional[bool] = None,
         **kwargs: Dict[str, Any],
     ) -> None:
-        super().__init__(compute_on_step=compute_on_step, **kwargs)
+        super().__init__(**kwargs)
         if 0 < power < 1:
             raise ValueError(f"Deviance Score is not defined for power={power}.")
 
