@@ -17,7 +17,7 @@
 # Authors: torchtext authors and @sluks
 # Date: 2020-07-18
 # Link: https://pytorch.org/text/_modules/torchtext/data/metrics.html#bleu_score
-from typing import Any, Dict, Optional, Sequence
+from typing import Any, Dict, Sequence
 
 from typing_extensions import Literal
 
@@ -36,17 +36,11 @@ class SacreBLEUScore(BLEUScore):
     The SacreBLEU implementation differs from the NLTK BLEU implementation in tokenization techniques.
 
     Args:
-        n_gram: Gram value ranged from 1 to 4 (Default 4)
+        n_gram: Gram value ranged from 1 to 4
         smooth: Whether to apply smoothing, see [2]
         tokenize: Tokenization technique to be used.
             Supported tokenization: ``['none', '13a', 'zh', 'intl', 'char']``
         lowercase:  If ``True``, BLEU score over lowercased text is calculated.
-        compute_on_step:
-            Forward only calls ``update()`` and returns None if this is set to False.
-
-            .. deprecated:: v0.8
-                Argument has no use anymore and will be removed v0.9.
-
         kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
      Raises:
@@ -74,16 +68,19 @@ class SacreBLEUScore(BLEUScore):
         and Skip-Bigram Statistics by Chin-Yew Lin and Franz Josef Och `Machine Translation Evolution`_
     """
 
+    is_differentiable: bool = False
+    higher_is_better: bool = True
+    full_state_update: bool = True
+
     def __init__(
         self,
         n_gram: int = 4,
         smooth: bool = False,
         tokenize: Literal["none", "13a", "zh", "intl", "char"] = "13a",
         lowercase: bool = False,
-        compute_on_step: Optional[bool] = None,
         **kwargs: Dict[str, Any],
     ):
-        super().__init__(n_gram=n_gram, smooth=smooth, compute_on_step=compute_on_step, **kwargs)
+        super().__init__(n_gram=n_gram, smooth=smooth, **kwargs)
         if tokenize not in AVAILABLE_TOKENIZERS:
             raise ValueError(f"Argument `tokenize` expected to be one of {AVAILABLE_TOKENIZERS} but got {tokenize}.")
 
