@@ -11,7 +11,8 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Optional, Tuple
+from time import perf_counter
+from typing import Any, Dict, Mapping, Optional, Sequence, Tuple, no_type_check
 
 import torch
 from torch import Tensor
@@ -243,7 +244,7 @@ def _check_classification_inputs(
             either from the shape of inputs, or the maximum label in the ``target`` and ``preds``
             tensor, where applicable.
         top_k:
-            Number of highest probability entries for each sample to convert to 1s - relevant
+            Number of the highest probability entries for each sample to convert to 1s - relevant
             only for inputs with probability predictions. The default value (``None``) will be
             interpreted as 1 for these inputs. If this parameter is set for multi-label inputs,
             it will take precedence over threshold.
@@ -342,7 +343,7 @@ def _input_format_classification(
 
     In binary case, targets are normally returned as ``(N,1)`` tensor, while preds are transformed
     into a binary tensor (elements become 1 if the probability is greater than or equal to
-    ``threshold`` or 0 otherwise). If ``multiclass=True``, then then both targets are preds
+    ``threshold`` or 0 otherwise). If ``multiclass=True``, then both targets are preds
     become ``(N, 2)`` tensors by a one-hot transformation; with the thresholding being applied to
     preds first.
 
@@ -461,7 +462,7 @@ def _input_format_classification_one_hot(
     Args:
         num_classes: number of classes
         preds: either tensor with labels, tensor with probabilities/logits or multilabel tensor
-        target: tensor with ground true labels
+        target: tensor with ground-true labels
         threshold: float used for thresholding multilabel input
         multilabel: boolean flag indicating if input is multilabel
 
@@ -503,7 +504,7 @@ def _check_retrieval_functional_inputs(
     target: Tensor,
     allow_non_binary_target: bool = False,
 ) -> Tuple[Tensor, Tensor]:
-    """Check ``preds`` and ``target`` tensors are of the same shape and of the correct dtype.
+    """Check ``preds`` and ``target`` tensors are of the same shape and of the correct data type.
 
     Args:
         preds: either tensor with scores/logits
@@ -535,7 +536,7 @@ def _check_retrieval_inputs(
     allow_non_binary_target: bool = False,
     ignore_index: Optional[int] = None,
 ) -> Tuple[Tensor, Tensor, Tensor]:
-    """Check ``indexes``, ``preds`` and ``target`` tensors are of the same shape and of the correct dtype.
+    """Check ``indexes``, ``preds`` and ``target`` tensors are of the same shape and of the correct data type.
 
     Args:
         indexes: tensor with queries indexes
@@ -580,7 +581,7 @@ def _check_retrieval_target_and_prediction_types(
     target: Tensor,
     allow_non_binary_target: bool = False,
 ) -> Tuple[Tensor, Tensor]:
-    """Check ``preds`` and ``target`` tensors are of the same shape and of the correct dtype.
+    """Check ``preds`` and ``target`` tensors are of the same shape and of the correct data type.
 
     Args:
         preds: either tensor with scores/logits
@@ -604,3 +605,121 @@ def _check_retrieval_target_and_prediction_types(
     preds = preds.float()
 
     return preds.flatten(), target.flatten()
+
+
+def _allclose_recursive(res1: Any, res2: Any, atol: float = 1e-8) -> bool:
+    """Utility function for recursively asserting that two results are within a certain tolerance."""
+    # single output compare
+    if isinstance(res1, Tensor):
+        return torch.allclose(res1, res2, atol=atol)
+    elif isinstance(res1, str):
+        return res1 == res2
+    elif isinstance(res1, Sequence):
+        return all(_allclose_recursive(r1, r2) for r1, r2 in zip(res1, res2))
+    elif isinstance(res1, Mapping):
+        return all(_allclose_recursive(res1[k], res2[k]) for k in res1.keys())
+    return res1 == res2
+
+
+@no_type_check
+def check_forward_full_state_property(
+    metric_class,
+    init_args: Dict[str, Any] = {},
+    input_args: Dict[str, Any] = {},
+    num_update_to_compare: Sequence[int] = [10, 100, 1000],
+    reps: int = 5,
+) -> bool:
+    """Utility function for checking if the new ``full_state_update`` property can safely be set to ``False`` which
+    will for most metrics results in a speedup when using ``forward``.
+
+    Args:
+        metric_class: metric class object that should be checked
+        init_args: dict containing arguments for initializing the metric class
+        input_args: dict containing arguments to pass to ``forward``
+        num_update_to_compare: if we successfully detech that the flag is safe to set to ``False``
+            we will run some speedup test. This arg should be a list of integers for how many
+            steps to compare over.
+        reps: number of repetitions of speedup test
+
+    Example (states in ``update`` are independent, save to set ``full_state_update=False``)
+        >>> from torchmetrics import ConfusionMatrix
+        >>> check_forward_full_state_property(
+        ...     ConfusionMatrix,
+        ...     init_args = {'num_classes': 3},
+        ...     input_args = {'preds': torch.randint(3, (10,)), 'target': torch.randint(3, (10,))},
+        ... )  # doctest: +ELLIPSIS
+        Full state for 10 steps took: ...
+        Partial state for 10 steps took: ...
+        Full state for 100 steps took: ...
+        Partial state for 100 steps took: ...
+        Full state for 1000 steps took: ...
+        Partial state for 1000 steps took: ...
+        Recommended setting `full_state_update=False`
+
+    Example (states in ``update`` are dependend meaning that ``full_state_update=True``):
+        >>> from torchmetrics import ConfusionMatrix
+        >>> class MyMetric(ConfusionMatrix):
+        ...     def update(self, preds, target):
+        ...         super().update(preds, target)
+        ...         # by construction make future states dependent on prior states
+        ...         if self.confmat.sum() > 20:
+        ...             self.reset()
+        >>> check_forward_full_state_property(
+        ...     MyMetric,
+        ...     init_args = {'num_classes': 3},
+        ...     input_args = {'preds': torch.randint(3, (10,)), 'target': torch.randint(3, (10,))},
+        ... )
+        Recommended setting `full_state_update=True`
+    """
+
+    class FullState(metric_class):
+        full_state_update = True
+
+    class PartState(metric_class):
+        full_state_update = False
+
+    fullstate = FullState(**init_args)
+    partstate = PartState(**init_args)
+
+    equal = True
+    for _ in range(num_update_to_compare[0]):
+        out1 = fullstate(**input_args)
+        try:  # if it fails, the code most likely need access to the full state
+            out2 = partstate(**input_args)
+        except RuntimeError:
+            equal = False
+            break
+        equal = equal & _allclose_recursive(out1, out2)
+
+    res1 = fullstate.compute()
+    try:  # if it fails, the code most likely need access to the full state
+        res2 = partstate.compute()
+    except RuntimeError:
+        equal = False
+    equal = equal & _allclose_recursive(res1, res2)
+
+    if not equal:  # we can stop early because the results did not match
+        print("Recommended setting `full_state_update=True`")
+        return
+
+    # Do timings
+    res = torch.zeros(2, len(num_update_to_compare), reps)
+    for i, metric in enumerate([fullstate, partstate]):
+        for j, t in enumerate(num_update_to_compare):
+            for r in range(reps):
+                start = perf_counter()
+                for _ in range(t):
+                    _ = metric(**input_args)
+                end = perf_counter()
+                res[i, j, r] = end - start
+                metric.reset()
+
+    mean = torch.mean(res, -1)
+    std = torch.std(res, -1)
+
+    for t in range(len(num_update_to_compare)):
+        print(f"Full state for {num_update_to_compare[t]} steps took: {mean[0, t]}+-{std[0, t]:0.3f}")
+        print(f"Partial state for {num_update_to_compare[t]} steps took: {mean[1, t]:0.3f}+-{std[1, t]:0.3f}")
+
+    faster = (mean[1, -1] < mean[0, -1]).item()  # if faster on average, we recommend upgrading
+    print(f"Recommended setting `full_state_update={not faster}`")
